"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.refreshToken = exports.isLoggedIn = exports.logout = exports.login = exports.isAuthError = void 0;
const inquirer_1 = __importDefault(require("inquirer"));
const amazon_cognito_identity_js_1 = require("amazon-cognito-identity-js");
const config = __importStar(require("../config"));
const std_1 = require("../utils/std");
const constants_1 = require("../constants");
const isAuthError = (params) => {
    const { errorText } = params;
    return (errorText.includes('Unable to find a signing key that matches') ||
        errorText.includes('Invalid Refresh Token'));
};
exports.isAuthError = isAuthError;
const login = async (params) => {
    const { username, password, userPoolId, clientId } = params;
    config.set('auth.user_pool_id', userPoolId);
    config.set('auth.client_id', clientId);
    const Pool = new amazon_cognito_identity_js_1.CognitoUserPool({
        UserPoolId: userPoolId,
        ClientId: clientId,
    });
    const user = new amazon_cognito_identity_js_1.CognitoUser({ Username: username, Pool });
    try {
        const refreshToken = await new Promise((resolve, reject) => user.authenticateUser(new amazon_cognito_identity_js_1.AuthenticationDetails({ Username: username, Password: password }), {
            onSuccess(result) {
                resolve(result.getRefreshToken().getToken());
            },
            onFailure(err) {
                reject(err);
            },
            async newPasswordRequired(userAttributes) {
                const { NewPassword } = await inquirer_1.default.prompt([
                    {
                        type: 'password',
                        name: 'NewPassword',
                        message: 'Enter new password',
                        mask: '*',
                        validate: (input) => {
                            if (!constants_1.PASSWORD_REGEX.test(input)) {
                                return 'Password must have minimum 8 characters, at least one uppercase letter, one lowercase letter and one digit';
                            }
                            return true;
                        },
                    },
                ]);
                delete userAttributes.email_verified;
                user.completeNewPasswordChallenge(NewPassword, userAttributes, {
                    onSuccess(result) {
                        resolve(result.getRefreshToken().getToken());
                    },
                    onFailure(err) {
                        reject(err);
                    },
                });
            },
        }));
        config.set('credentials.user', username);
        config.set('credentials.refresh_token', refreshToken);
    }
    catch (e) {
        config.set('credentials.user', username);
        config.del('credentials.refresh_token', 'credentials.token');
        throw e;
    }
};
exports.login = login;
const logout = async () => {
    std_1.logger.info({
        Username: config.get('credentials.user'),
        RefreshToken: config.get('credentials.refresh_token'),
        Token: config.get('credentials.token'),
    });
    config.del('credentials.user');
    config.del('credentials.refresh_token');
    config.del('credentials.token');
};
exports.logout = logout;
const isLoggedIn = () => {
    return (config.get('auth.user_pool_id') != null &&
        config.get('auth.client_id') != null &&
        config.get('credentials.user') != null &&
        config.get('credentials.refresh_token') != null);
};
exports.isLoggedIn = isLoggedIn;
// TODO: verify jwt and check expiration instead of refreshing session every time
const refreshToken = async () => {
    const Pool = new amazon_cognito_identity_js_1.CognitoUserPool({
        UserPoolId: config.get('auth.user_pool_id'),
        ClientId: config.get('auth.client_id'),
    });
    try {
        const [Username, RefreshToken] = config.get('credentials.user', 'credentials.refresh_token');
        const user = new amazon_cognito_identity_js_1.CognitoUser({ Username, Pool });
        const token = await new Promise((resolve, reject) => user.refreshSession({ getToken: () => RefreshToken }, (err, session) => {
            if (err) {
                return reject(err);
            }
            return resolve(session.getIdToken().getJwtToken());
        }));
        config.set('credentials.token', token);
        return token;
    }
    catch (error) {
        if ((0, exports.isAuthError)({ errorText: `${error}` })) {
            await (0, exports.logout)();
        }
        if (`${error}`.includes('Username and Pool information are required')) {
            throw new Error('You must be logged in to use this command');
        }
        throw error;
    }
};
exports.refreshToken = refreshToken;
//# sourceMappingURL=auth.js.map