"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const resolve_cloud_sdk_1 = require("resolve-cloud-sdk");
const url_1 = require("url");
const dns_1 = require("dns");
const node_fetch_1 = __importDefault(require("node-fetch"));
const std_1 = require("../utils/std");
const auth_1 = require("./auth");
const config = __importStar(require("../config"));
let client;
const createCloudSdkClient = async () => {
    if (client != null) {
        return client;
    }
    const sdk = (0, resolve_cloud_sdk_1.createCloudSdk)();
    let setupOptions = {
        logger: std_1.logger,
        fetch: node_fetch_1.default,
    };
    client = {
        ...Object.entries(sdk).reduce((acc, [methodName, callback]) => {
            acc[methodName] = async (...args) => {
                try {
                    return await callback(...args);
                }
                catch (error) {
                    if ((0, auth_1.isAuthError)({ errorText: `${error}` })) {
                        await (0, auth_1.logout)();
                    }
                    throw error;
                }
            };
            return acc;
        }, {}),
        async refreshToken() {
            if ((0, auth_1.isLoggedIn)()) {
                setupOptions.token = await (0, auth_1.refreshToken)();
                sdk.setup(setupOptions);
            }
        },
    };
    const { host } = new url_1.URL(config.get('api_url'));
    for (;;) {
        try {
            const ips = await dns_1.promises.resolve4(host);
            const ip = ips[Math.floor(Math.random() * ips.length)];
            std_1.logger.trace(`DNS resolved: ${host} -> ${ip}`);
            const baseUrl = `https://${ip}:443`;
            setupOptions = {
                ...setupOptions,
                baseUrl,
                baseHeaders: {
                    Host: host,
                },
            };
            sdk.setup(setupOptions);
            await client.heartbeat();
            break;
        }
        catch (error) {
            if (!(0, resolve_cloud_sdk_1.isNetworkError)({ errorText: `${error}` })) {
                throw error;
            }
        }
    }
    if (config.get('auth.client_id') == null || config.get('auth.user_pool_id') == null) {
        const { clientId, userPoolId } = await client.getClientAppConfig({});
        config.set('auth.client_id', clientId);
        config.set('auth.user_pool_id', userPoolId);
    }
    await client.refreshToken();
    return client;
};
exports.default = createCloudSdkClient;
//# sourceMappingURL=client.js.map