"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const dateformat_1 = __importDefault(require("dateformat"));
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }) => {
    const result = await client.listCertificates();
    (0, std_1.out)((0, columnify_1.default)(result.map((item) => {
        const { certificateId, domainName, additionalNames, issuer, importedAt, notBefore, notAfter, } = item;
        return {
            id: certificateId,
            'domain name': domainName,
            'additional names': additionalNames.length === 0 ? 'N/A' : additionalNames.join(', '),
            issuer,
            imported: importedAt ? (0, dateformat_1.default)(new Date(importedAt), 'm/d/yy HH:MM:ss') : 'N/A',
            'not before': notBefore ? (0, dateformat_1.default)(new Date(notBefore), 'm/d/yy HH:MM:ss') : 'N/A',
            'not after': notAfter ? (0, dateformat_1.default)(new Date(notAfter), 'm/d/yy HH:MM:ss') : 'N/A',
        };
    }), {
        minWidth: 20,
        columns: [
            'id',
            'domain name',
            'additional names',
            'issuer',
            'imported',
            'not before',
            'not after',
        ],
        config: {
            'additional names': {
                maxWidth: 50,
            },
        },
    }));
});
exports.command = 'list';
exports.aliases = ['ls', '$0'];
exports.describe = chalk_1.default.green('display a list of available certificates');
const builder = () => { };
exports.builder = builder;
//# sourceMappingURL=list.js.map