"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.aliases = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const qrcode_terminal_1 = __importDefault(require("qrcode-terminal"));
const dotenv_1 = __importDefault(require("dotenv"));
const resolve_cloud_sdk_1 = require("resolve-cloud-sdk");
const command_handler_1 = __importDefault(require("../command-handler"));
const packager_1 = __importStar(require("../packager"));
const config = __importStar(require("../config"));
const std_1 = require("../utils/std");
const fetch_1 = __importDefault(require("../utils/fetch"));
const import_1 = require("./event-stores/import");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const resolveVersion = config.getResolvePackageVersion();
    const { 'skip-build': skipBuild, configuration, name: nameOverride, 'event-store-id': receivedEventStoreId, qr: generateQrCode, environment, 'npm-registry': npmRegistry, domain, envs, 'import-from': eventStorePath, } = params;
    void environment;
    const applicationName = config.getApplicationIdentifier(nameOverride);
    if (!skipBuild) {
        await (0, packager_1.default)(configuration, applicationName);
    }
    else {
        std_1.logger.trace(`skipping the application build phase`);
    }
    let deployment = null;
    let eventStoreId = receivedEventStoreId;
    std_1.logger.trace(`requesting the list of existing deployments`);
    const existingDeployment = await client.getDeploymentByApplicationName({ applicationName });
    if (existingDeployment != null) {
        deployment = existingDeployment;
    }
    if (deployment == null) {
        std_1.logger.start(`deploying the "${applicationName}" application to the cloud`);
        if (receivedEventStoreId == null) {
            void ({ eventStoreId } = await client.createEventStore({
                version: resolveVersion,
            }));
            if (eventStorePath != null) {
                await (0, import_1.importEventStore)({
                    client,
                    eventStoreId,
                    eventStorePath,
                });
            }
        }
        const domains = domain == null ? [] : domain.split(',');
        const createdDeployment = await client.createDeployment({
            applicationName,
            version: resolveVersion,
            eventStoreId,
            domain: domains[0],
        });
        for (let index = 1; index < domains.length; index++) {
            await client.setDeploymentDomain({
                deploymentId: createdDeployment.deploymentId,
                domain: domains[index],
            });
        }
        for (const item of createdDeployment.domains) {
            if (!domains.includes(item)) {
                domains.push(item);
            }
        }
        deployment = {
            deploymentId: createdDeployment.deploymentId,
            applicationName,
            version: resolveVersion,
            domains,
            eventStoreId,
        };
    }
    else if (receivedEventStoreId != null) {
        await client.linkDeployment({
            deploymentId: deployment.deploymentId,
            eventStoreId: receivedEventStoreId,
        });
    }
    if (!(0, resolve_cloud_sdk_1.intersectsVersions)(deployment.version, resolveVersion)) {
        throw new Error('The minor version of reSolve in the application you are trying to deploy does not match the version used by the current cloud deployment. \n' +
            `Local: ${resolveVersion} \n` +
            `Deployed: ${deployment.version} \n` +
            'To upgrade to a new minor version, please create a new deployment.');
    }
    const { codeUploadUrl, staticUploadUrl } = await client.getDeploymentUploadSignedUrl({
        deploymentId: deployment.deploymentId,
    });
    std_1.logger.debug(`upload code.zip and static.zip`);
    try {
        await Promise.all([
            {
                zipPath: packager_1.codeZipPath,
                uploadUrl: codeUploadUrl,
            },
            {
                zipPath: packager_1.staticZipPath,
                uploadUrl: staticUploadUrl,
            },
        ].map(({ zipPath, uploadUrl }) => new Promise(async (resolve, reject) => {
            const fileSizeInBytes = fs_1.default.lstatSync(zipPath).size;
            const contentType = 'application/zip';
            const fileStream = fs_1.default.createReadStream(zipPath);
            try {
                await (0, fetch_1.default)(uploadUrl, {
                    method: 'PUT',
                    headers: {
                        'Content-Length': fileSizeInBytes.toString(),
                        'Content-Type': contentType,
                    },
                    body: fileStream,
                });
                resolve();
            }
            catch (error) {
                reject(error);
            }
        })));
        std_1.logger.debug(`code.zip and static.zip have been uploaded`);
    }
    catch (error) {
        std_1.logger.debug(`failed to upload code.zip and static.zip`);
        throw error;
    }
    await client.buildDeployment({
        deploymentId: deployment.deploymentId,
        npmRegistry,
    });
    if (envs != null) {
        await client.setEnvironmentVariables({
            deploymentId: deployment.deploymentId,
            variables: dotenv_1.default.parse(Buffer.from(envs.join('\n'))),
        });
    }
    await client.bootstrapDeployment({
        deploymentId: deployment.deploymentId,
    });
    const availableDomains = Array.from(new Set([...(domain == null ? [] : domain.split(',')), ...deployment.domains]));
    std_1.logger.success(`"${applicationName}" available at ${availableDomains
        .map((domainName) => `https://${domainName}`)
        .join(' ')}`);
    if (generateQrCode) {
        qrcode_terminal_1.default.generate(availableDomains[0], { small: true });
    }
});
exports.aliases = undefined;
exports.command = 'deploy';
exports.describe = chalk_1.default.green('deploy a reSolve application to the cloud');
const builder = (yargs) => yargs
    .option('skip-build', {
    describe: 'skip installing npm packages on the cloud',
    type: 'boolean',
    default: false,
})
    .option('configuration', {
    alias: 'c',
    describe: 'the launch mode used to run the deployed application',
    type: 'string',
    default: 'cloud',
})
    .option('name', {
    alias: 'n',
    describe: 'a unique name for the application, e.g. dev or prod',
    type: 'string',
})
    .option('event-store-id', {
    alias: 'es',
    describe: `id of an existing event store to use in the the initial deployment`,
    type: 'string',
})
    .option('qr', {
    describe: 'generate QR code containing the application URL',
    type: 'boolean',
    default: false,
})
    .option('environment', {
    describe: 'a list of key=value pairs that define environment variables for the running application',
    alias: ['env', 'envs'],
    type: 'array',
})
    .option('npm-registry', {
    describe: 'a custom NPM registry URL',
    type: 'string',
    deprecated: true,
})
    .option('domain', {
    describe: 'a verified domain to which to bind the deployed application',
    type: 'string',
    alias: ['domains'],
})
    .option('import-from', {
    describe: 'a path to the event store directory',
    type: 'string',
})
    .conflicts('event-store-id', 'import-from')
    .group([
    'skip-build',
    'configuration',
    'name',
    'event-store-id',
    'qr',
    'environment',
    'npm-registry',
    'domain',
    'import-from',
], 'Options:');
exports.builder = builder;
//# sourceMappingURL=deploy.js.map