"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = exports.getDeployment = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const std_1 = require("../utils/std");
const command_handler_1 = __importDefault(require("../command-handler"));
const getDeployment = async (params) => {
    const { client, deploymentId } = params;
    const deployment = await client.describeDeployment({
        deploymentId,
    });
    return {
        ...deployment,
        applicationUrl: deployment.domains.map((domain) => `https://${domain}`).join(' , '),
    };
};
exports.getDeployment = getDeployment;
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { format, deploymentId } = params;
    const deployment = await (0, exports.getDeployment)({
        client,
        deploymentId,
    });
    if ((0, std_1.renderByTemplate)(format, deployment)) {
        return;
    }
    const { applicationName, version, eventStoreId, domains, applicationUrl } = deployment;
    (0, std_1.out)((0, columnify_1.default)({
        'application-name': applicationName,
        'deployment-id': deploymentId,
        'application-url': applicationUrl,
        domain: domains,
        version,
        'event-store-id': eventStoreId ?? 'N/A',
    }, { minWidth: 20, showHeaders: false, preserveNewLines: true }));
});
exports.command = 'describe <deployment-id>';
exports.aliases = ['get'];
exports.describe = chalk_1.default.green('display information on the specified deployment');
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('format', {
    describe: `Format the output using a mustache template http://mustache.github.io/ 
      Possible fields: deploymentId, applicationName, eventStoreId, domainName, version, applicationUrl`,
    type: 'string',
})
    .group(['format'], 'Options:')
    .example([
    [
        'EVENT_STORE=$(yarn -s resolve-cloud describe <deployment-id> --format="{{ eventStoreId }}")',
        'Save event-store-id in env',
    ],
]);
exports.builder = builder;
//# sourceMappingURL=describe.js.map