"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { aliases, 'certificate-id': certificateId, 'domain-id': rawDomainId } = params;
    const { domainId, domainName, verificationCode } = await client.createDomain({
        domainId: rawDomainId,
        certificateId,
        aliases: aliases.split(',').map((alias) => alias.trim()),
    });
    std_1.logger.info(`Your domain "${domainName}" with id "${domainId}"`);
    if (verificationCode != null) {
        std_1.logger.info(`Your verification code is ${verificationCode}`);
        std_1.logger.info(`Add the following TXT verification record to your domain host's DNS settings: resolve-verification=${verificationCode}`);
    }
});
exports.command = 'create';
exports.aliases = ['register'];
exports.describe = chalk_1.default.green('register a new domain');
const builder = (yargs) => yargs
    .option('certificate-id', {
    alias: 'cert',
    describe: 'the id of an SSL certificate to use',
    type: 'string',
    demand: 'a certificate id is required',
})
    .option('aliases', {
    alias: 'a',
    describe: 'aliases for domain',
    type: 'string',
    demand: 'an aliases is required',
})
    .option('domain-id', {
    alias: 'id',
    describe: 'the id for existing domain',
    type: 'string',
})
    .group(['certificate-id', 'aliases', 'domain-id'], 'Options:')
    .example([
    [
        'yarn resolve-cloud domains create --aliases="<custom-domain-name>","*.<custom-domain-name>" --certificate-id=<certificate-id>',
        'Create a new domain',
    ],
]);
exports.builder = builder;
//# sourceMappingURL=create.js.map