"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, format } = params;
    if (format != null) {
        (0, std_1.disableLogger)();
    }
    const result = await client.listEnvironmentVariables({
        deploymentId,
    });
    if (format) {
        Object.entries(result).map(([key, value]) => (0, std_1.renderByTemplate)(format, {
            name: key,
            value,
        }));
        return;
    }
    (0, std_1.out)((0, columnify_1.default)(result, {
        columnSplitter: '    ',
        columns: ['name', 'value'],
    }));
});
exports.command = `list <deployment-id>`;
exports.describe = chalk_1.default.green('display a list of environment variables');
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('format', {
    describe: `Format the output using the given mustache template http://mustache.github.io/
      Possible fields: name, value`,
    type: 'string',
})
    .group(['format'], 'Options:')
    .example([
    ['yarn resolve-cloud env list --format="{{ name }}:{{ value }}"', 'Formatted output list'],
]);
exports.builder = builder;
//# sourceMappingURL=list.js.map