"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { 'event-store-id': sourceEventStoreId, format } = params;
    if (format != null) {
        (0, std_1.disableLogger)();
    }
    const { eventStoreId: targetEventStoreId } = await client.cloneEventStore({
        eventStoreId: sourceEventStoreId,
    });
    if ((0, std_1.renderByTemplate)(format, { eventStoreId: targetEventStoreId })) {
        return;
    }
    std_1.logger.success(`Event store with "${targetEventStoreId}" id has been created`);
});
exports.command = 'clone <event-store-id>';
exports.describe = chalk_1.default.green('clone an existing event store');
const builder = (yargs) => yargs
    .positional('event-store-id', {
    describe: chalk_1.default.green("an existing event store's id"),
    type: 'string',
})
    .option('format', {
    describe: `Format the output using the given mustache template http://mustache.github.io/
      Possible fields: eventStoreId`,
    type: 'string',
})
    .group(['format'], 'Options:')
    .example([
    ['yarn resolve-cloud event-stores create', 'Create new empty event store'],
    [
        'yarn resolve-cloud event-stores clone <event-store-id>',
        'Clone an existing event store by id',
    ],
    [
        'NEW_EVENT_STORE=$(yarn -s resolve-cloud event-stores clone <event-store-id> --format="{{ eventStoreId }}")',
        'Clone an existing event store and save its event-store-id in env',
    ],
]);
exports.builder = builder;
//# sourceMappingURL=clone.js.map