"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
const config_1 = require("../../config");
const import_1 = require("./import");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { 'import-from': eventStorePath, format } = params;
    if (format != null) {
        (0, std_1.disableLogger)();
    }
    const version = (0, config_1.getResolvePackageVersion)();
    const { eventStoreId } = await client.createEventStore({
        version,
    });
    std_1.logger.info(`Event store ID: ${eventStoreId}`);
    if (eventStorePath != null) {
        await (0, import_1.importEventStore)({
            client,
            eventStorePath,
            eventStoreId,
            format,
        });
    }
    if ((0, std_1.renderByTemplate)(format, { eventStoreId })) {
        return;
    }
    std_1.logger.success(`Event store with "${eventStoreId}" id has been created`);
});
exports.command = 'create';
exports.describe = chalk_1.default.green('create an event-store');
const builder = (yargs) => yargs
    .option('import-from', {
    describe: 'path to the previously exported event-store directory',
    type: 'string',
})
    .option('format', {
    describe: `Format the output using the given mustache template http://mustache.github.io/
      Possible fields: eventStoreId`,
    type: 'string',
})
    .group(['import-from', 'format'], 'Options:')
    .example([
    ['yarn resolve-cloud event-stores create', 'Create new empty event-store'],
    [
        'yarn resolve-cloud event-stores create --import-from=<path-to-event-store-directory>',
        'Create a new event store and import data from a previously exported event store directory',
    ],
    [
        'NEW_EVENT_STORE=$(yarn -s resolve-cloud event-stores create --format="{{ eventStoreId }}")',
        'Create a new empty event store and save its event-store-id in env',
    ],
]);
exports.builder = builder;
//# sourceMappingURL=create.js.map