"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const inquirer_1 = __importDefault(require("inquirer"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { 'event-store-id': eventStoreId, 'deployment-id': deploymentId, force } = params;
    const { eventStoreId: linkedEventStoreId } = await client.describeDeployment({
        deploymentId,
    });
    if (!force && linkedEventStoreId != null) {
        const { confirm } = await inquirer_1.default.prompt([
            {
                type: 'confirm',
                name: 'confirm',
                message: 'This application is already linked to an event-store. Are you sure you want to switch the existing event-store with the specified one?',
            },
        ]);
        if (!confirm) {
            return;
        }
    }
    await client.linkDeployment({
        eventStoreId,
        deploymentId,
    });
    std_1.logger.success(`Link ${eventStoreId} to ${deploymentId} successfully completed!`);
});
exports.command = 'link <event-store-id> <deployment-id>';
exports.describe = chalk_1.default.green('link event store to deployment');
const builder = (yargs) => yargs
    .positional('event-store-id', {
    describe: chalk_1.default.green("an existing event store's id"),
    type: 'string',
})
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('force', {
    describe: 'skip all prompts and run non-interactively',
    type: 'boolean',
    default: false,
});
exports.builder = builder;
//# sourceMappingURL=link.js.map