"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const semver_1 = __importDefault(require("semver"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { format } = params;
    const result = await client.listEventStores();
    if (format) {
        result.map(({ eventStoreId, version: esVersion, linkedDeployments, events, secrets, createdAt, modifiedAt, isFrozen, }) => (0, std_1.renderByTemplate)(format, {
            eventStoreId,
            id: eventStoreId,
            version: esVersion,
            linkedDeployments: linkedDeployments ?? 'N/A',
            events: events ?? 'N/A',
            secrets: secrets ?? 'N/A',
            created: createdAt != null && createdAt !== 0 ? new Date(createdAt).toISOString() : 'N/A',
            createdAt: createdAt != null && createdAt !== 0 ? new Date(createdAt).toISOString() : 'N/A',
            latestEvent: modifiedAt != null && modifiedAt !== 0 ? new Date(modifiedAt).toISOString() : 'N/A',
            modifiedAt: modifiedAt != null && modifiedAt !== 0 ? new Date(modifiedAt).toISOString() : 'N/A',
            frozen: isFrozen != null ? `${isFrozen}` : 'N/A',
            isFrozen: isFrozen != null ? `${isFrozen}` : 'N/A',
        }));
        return;
    }
    (0, std_1.out)((0, columnify_1.default)(result
        .map(({ eventStoreId, version: esVersion, linkedDeployments, events, secrets, createdAt, modifiedAt, isFrozen, }) => ({
        id: eventStoreId,
        version: esVersion,
        'linked deployments': linkedDeployments ?? 'N/A',
        events: events ?? 'N/A',
        secrets: secrets ?? 'N/A',
        created: createdAt != null && createdAt !== 0 ? new Date(createdAt).toISOString() : 'N/A',
        'latest event': modifiedAt != null && modifiedAt !== 0 ? new Date(modifiedAt).toISOString() : 'N/A',
        frozen: isFrozen != null ? `${isFrozen}` : 'N/A',
    }))
        .sort((a, b) => (semver_1.default.lt(a.version, b.version) ? 1 : -1)), {
        minWidth: 6,
        truncate: true,
        columnSplitter: '    ',
        columns: [
            'id',
            'linked deployments',
            'version',
            'events',
            'secrets',
            'created',
            'latest event',
            'frozen',
        ],
    }));
});
exports.command = 'list';
exports.aliases = ['ls', '$0'];
exports.describe = chalk_1.default.green('display a list of event stores');
const builder = (yargs) => yargs
    .option('format', {
    describe: `Format the output using a mustache template http://mustache.github.io/ 
        Possible fields: id, version, linkedDeployments, events, secrets, created, latestEvent, frozen`,
    type: 'string',
})
    .group(['format'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=list.js.map