"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const semver_1 = __importDefault(require("semver"));
const std_1 = require("../utils/std");
const command_handler_1 = __importDefault(require("../command-handler"));
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { format } = params;
    const result = await client.listDeployments();
    if (format) {
        result.map((deployment) => (0, std_1.renderByTemplate)(format, {
            ...deployment,
            domain: deployment.domains,
            domainName: deployment.domains,
            applicationUrl: deployment.domains.map((domain) => `https://${domain}`).join(' , '),
        }));
        return;
    }
    (0, std_1.out)((0, columnify_1.default)(result
        .map(({ deploymentId, version, eventStoreId, applicationName, domains }) => ({
        'application-name': applicationName,
        'deployment-id': deploymentId,
        version,
        'event-store-id': eventStoreId ?? 'N/A',
        domain: domains.join(','),
    }))
        .sort((a, b) => (semver_1.default.lt(a.version, b.version) ? 1 : -1)), {
        columnSplitter: '    ',
        columns: ['application-name', 'deployment-id', 'domain', 'version', 'event-store-id'],
    }));
});
exports.command = 'list';
exports.aliases = ['ls'];
exports.describe = chalk_1.default.green('display a list of available deployments');
const builder = (yargs) => yargs
    .option('format', {
    describe: `Format the output using a mustache template http://mustache.github.io/ 
      Possible fields: deploymentId, applicationName, eventStoreId, domain, version, applicationUrl`,
    type: 'string',
})
    .group(['format'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=list.js.map