"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const timers_1 = require("timers");
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, 'start-time': startTime, 'end-time': endTime, 'filter-pattern': filterPattern, 'stream-limit': streamLimit, follow, offset = 15000, } = params;
    const logs = await client.getLogs({
        deploymentId,
        startTime,
        endTime,
        filterPattern,
        streamLimit,
    });
    if (logs !== '') {
        (0, std_1.out)(logs);
    }
    if (follow) {
        // eslint-disable-next-line no-constant-condition
        while (true) {
            const tempStartTime = Date.now() - offset;
            // eslint-disable-next-line @typescript-eslint/no-shadow
            const followLogs = await client.getLogs({
                deploymentId,
                startTime: tempStartTime,
                endTime,
                filterPattern,
                streamLimit,
            });
            if (followLogs !== '') {
                (0, std_1.out)(followLogs);
            }
            await new Promise((resolve) => (0, timers_1.setTimeout)(resolve, offset));
        }
    }
});
exports.command = 'get <deployment-id>';
exports.aliases = ['$0'];
exports.describe = chalk_1.default.green('retrieve application logs from the cloud');
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('start-time', {
    alias: 's',
    describe: 'the timestamp at which the log should start',
    type: 'string',
})
    .option('end-time', {
    alias: 'e',
    describe: 'the timestamp at which the log should end',
    type: 'string',
})
    .option('filter-pattern', {
    alias: 'f',
    describe: 'a pattern used to filter the output',
    type: 'string',
})
    .option('stream-limit', {
    alias: 'l',
    describe: 'a number of streams used to fetch logs',
    type: 'number',
})
    .option('follow', {
    describe: 'a flag that defines that logs should be streamed in real time',
    type: 'boolean',
})
    .option('offset', {
    describe: 'the time interval between log updates',
    type: 'number',
})
    .group(['start-time', 'end-time', 'filter-pattern', 'stream-limit', 'follow', 'offset'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=get.js.map