"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const std_1 = require("../utils/std");
const command_handler_1 = __importDefault(require("../command-handler"));
const optionalWait = async (promise, flag) => {
    if (flag) {
        await promise;
    }
};
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, 'with-event-store': withEventStore, wait } = params;
    std_1.logger.trace(`requesting deployment removal`);
    let timer = null;
    try {
        await Promise.race([
            client.shutdownDeployment({
                deploymentId,
            }),
            new Promise((resolve) => {
                timer = setTimeout(resolve, 60000);
            }),
        ]);
    }
    catch (error) {
        if (!/Options "dbClusterOrInstanceArn" and "awsSecretStoreArn" are mandatory/.test(error.message)) {
            std_1.logger.warn(`Shutdown deployment failed with "${error.message}"`);
        }
    }
    await optionalWait(client.dropDeployment({
        deploymentId,
        withEventStore,
    }), wait);
    clearTimeout(timer);
    if (wait) {
        std_1.logger.success(`Deployment "${deploymentId}" successfully removed`);
    }
    else {
        std_1.logger.success(`Deployment "${deploymentId}" has been scheduled for removal`);
    }
});
exports.command = 'remove <deployment-id>';
exports.aliases = ['rm'];
exports.describe = chalk_1.default.green('remove an application deployment with all its data');
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('with-event-store', {
    describe: 'remove the linked event-store',
    type: 'boolean',
    default: false,
})
    .option('wait', {
    describe: 'wait until the remove operation is complete',
    type: 'boolean',
    default: true,
})
    .group(['with-event-store', 'wait'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=remove.js.map