"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, format } = params;
    const result = await client.listSagas({ deploymentId });
    if (format) {
        result.map(({ name, status, successEvent, failedEvent, errors }) => (0, std_1.renderByTemplate)(format, {
            name,
            status,
            successEvent: (0, std_1.formatEvent)(successEvent).trim(),
            failedEvent: (0, std_1.formatEvent)(failedEvent).trim(),
            errors: Array.isArray(errors) ? `${errors.map((e) => e.stack).join('\n')}` : 'N\\A',
        }));
        return;
    }
    (0, std_1.out)((0, columnify_1.default)(result.map((item) => {
        const { name, status, successEvent, failedEvent, errors } = item;
        return {
            name,
            status,
            'success event': (0, std_1.formatEvent)(successEvent),
            'failed event': (0, std_1.formatEvent)(failedEvent),
            'last error': Array.isArray(errors) ? `${errors.map((e) => e.stack).join('\n')}` : 'N\\A',
        };
    }), {
        columnSplitter: '    ',
        columns: ['name', 'status', 'success event', 'failed event', 'last error'],
    }));
});
exports.command = 'list <deployment-id>';
exports.aliases = ['ls', '$0'];
exports.describe = chalk_1.default.green("display a list of an application's sagas");
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('format', {
    describe: `Format the output using a mustache template http://mustache.github.io/ 
      Possible fields: name, status, successEvent, failedEvent, errors`,
    type: 'string',
})
    .group(['format'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=list.js.map