"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../command-handler"));
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId } = params;
    const result = await client.listSagas({
        deploymentId,
    });
    const promises = [];
    const errors = [];
    for (const { name: sagaName } of result) {
        promises.push(Promise.resolve()
            .then(() => client.pauseSaga({
            deploymentId,
            sagaName,
        }))
            .catch((error) => errors.push(error)));
    }
    await Promise.all(promises);
    if (errors.length > 0) {
        const error = new Error(errors.map(({ message }) => message).join('\n'));
        error.stack = errors.map(({ stack }) => stack).join('\n');
        throw error;
    }
});
exports.command = 'pause-all <deployment-id>';
exports.describe = chalk_1.default.green('stop handling events for all sagas');
const builder = (yargs) => yargs.positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
});
exports.builder = builder;
//# sourceMappingURL=pause-all.js.map