"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const columnify_1 = __importDefault(require("columnify"));
const chalk_1 = __importDefault(require("chalk"));
const command_handler_1 = __importDefault(require("../../../command-handler"));
const std_1 = require("../../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, saga: sagaName, format } = params;
    const result = await client.listSagaProperties({
        deploymentId,
        sagaName,
    });
    if (format) {
        Object.entries(result).map(([key, value]) => (0, std_1.renderByTemplate)(format, {
            name: key,
            value,
        }));
        return;
    }
    if (result) {
        (0, std_1.out)((0, columnify_1.default)(result, {
            columnSplitter: '    ',
            columns: ['name', 'value'],
        }));
    }
});
exports.command = 'list <deployment-id> <saga>';
exports.aliases = ['ls', '$0'];
exports.describe = chalk_1.default.green('show a list of assigned properties');
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .positional('saga', {
    describe: chalk_1.default.green("an existing saga's name"),
    type: 'string',
})
    .option('format', {
    describe: `Format the output using the given mustache template http://mustache.github.io/
      Possible fields: name, value`,
    type: 'string',
})
    .group(['format'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=list.js.map