"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.builder = exports.describe = exports.aliases = exports.command = exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const columnify_1 = __importDefault(require("columnify"));
const dateformat_1 = __importDefault(require("dateformat"));
const command_handler_1 = __importDefault(require("../../command-handler"));
const std_1 = require("../../utils/std");
exports.handler = (0, command_handler_1.default)(async ({ client }, params) => {
    const { deploymentId, 'start-time': startTime, 'end-time': endTime } = params;
    const result = await client.getSummaries({
        deploymentId,
        startTime,
        endTime,
    });
    if (result) {
        (0, std_1.out)((0, columnify_1.default)(result.map(({ Id, ResponseTime, Http }) => ({
            id: Id,
            status: Http?.HttpStatus ?? 'N/A',
            url: Http?.HttpURL ?? '',
            method: Http?.HttpMethod ?? '',
            time: Id == null
                ? 'N/A'
                : `${(0, dateformat_1.default)(new Date(parseInt(Id.split('-')[1], 16) * 1000), 'm/d/yy HH:MM:ss')}`,
            latency: ResponseTime,
        })), {
            minWidth: 20,
            columns: ['time', 'id', 'latency', 'status', 'method', 'url'],
        }));
    }
});
exports.command = 'summary <deployment-id>';
exports.aliases = [];
exports.describe = chalk_1.default.green("retrieve the list of an application's performance traces");
const builder = (yargs) => yargs
    .positional('deployment-id', {
    describe: chalk_1.default.green("an existing deployment's id"),
    type: 'string',
})
    .option('start-time', {
    alias: 's',
    describe: 'the timestamp at which the traces should start',
    type: 'string',
    required: true,
})
    .option('end-time', {
    alias: 'e',
    describe: 'the timestamp at which the traces should end',
    type: 'string',
    required: true,
})
    .group(['start-time', 'end-time'], 'Options:');
exports.builder = builder;
//# sourceMappingURL=summary.js.map