"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApplicationIdentifier = exports.getResolvePackageVersion = exports.del = exports.set = exports.get = void 0;
const os_1 = __importDefault(require("os"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const rc_1 = __importDefault(require("rc"));
const semver = __importStar(require("semver"));
const configHelpers = __importStar(require("./utils/config-helpers"));
const configFile = path_1.default.join(os_1.default.homedir(), '.resolverc');
const load = () => {
    const conf = (0, rc_1.default)('resolve');
    return Object.entries(conf).reduce((obj, [key, value]) => {
        obj[key.toLowerCase()] = value;
        return obj;
    }, {});
};
const loadFile = () => {
    try {
        return JSON.parse(fs_1.default.readFileSync(configFile, 'utf8'));
    }
    catch (e) {
        return {};
    }
};
const saveFile = (conf) => {
    fs_1.default.writeFileSync(configFile, JSON.stringify(conf, null, 2), 'utf8');
};
const get = (...selectors) => {
    const conf = load();
    return selectors
        .map((selector) => configHelpers.get(conf, selector))
        .reduce((acc, value) => {
        if (acc === null) {
            return value;
        }
        return [].concat(acc, value);
    }, null);
};
exports.get = get;
const set = (selector, value) => {
    const conf = loadFile();
    configHelpers.set(conf, selector, value);
    saveFile(conf);
};
exports.set = set;
const del = (...selectors) => {
    const conf = loadFile();
    selectors.map((selector) => configHelpers.unset(conf, selector));
    saveFile(conf);
};
exports.del = del;
const getResolvePackageVersion = () => {
    let pkg = null;
    try {
        pkg = JSON.parse(fs_1.default.readFileSync('package.json', 'utf8'));
    }
    catch (error) {
        throw new Error('Failed to read "package.json" file.');
    }
    const keys = Object.keys(pkg.dependencies);
    const resolvePackageNames = keys.filter((name) => ((name.startsWith('resolve') &&
        name !== 'resolve-cloud' &&
        name !== 'resolve-cloud-common') ||
        name.startsWith('@reimagined/') ||
        name.startsWith('@resolve-js/')) &&
        pkg.dependencies[name] != null &&
        !pkg.dependencies[name].startsWith('file:'));
    const packageName = resolvePackageNames[0];
    if (packageName == null) {
        throw new Error('The resolve packages were not found');
    }
    const version = pkg.dependencies[packageName];
    // eslint-disable-next-line no-restricted-syntax
    for (const name of resolvePackageNames) {
        const packageVersion = pkg.dependencies[name];
        const firstVersion = semver.valid(semver.coerce(packageVersion));
        const secondVersion = semver.valid(semver.coerce(version));
        if (firstVersion == null || secondVersion == null || semver.neq(firstVersion, secondVersion)) {
            throw new Error(`The resolve package versions must be the same [${resolvePackageNames
                .map((item) => `"${item}"`)
                .join(', ')}]`);
        }
    }
    if (version != null && version.constructor === String) {
        return version;
    }
    else {
        throw new Error('Failed to get resolve package version');
    }
};
exports.getResolvePackageVersion = getResolvePackageVersion;
const getApplicationIdentifier = (nameOverride) => {
    let pkg = null;
    try {
        pkg = JSON.parse(fs_1.default.readFileSync('package.json', 'utf8'));
    }
    catch (error) {
        throw new Error('Failed to read "package.json" file.');
    }
    const name = nameOverride != null ? nameOverride : pkg.name;
    if (name == null || name.constructor !== String || `${name}`.trim().length < 1) {
        throw new Error('incorrect application name (wrong working directory?)');
    }
    return name;
};
exports.getApplicationIdentifier = getApplicationIdentifier;
//# sourceMappingURL=config.js.map