#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const chalk_1 = __importDefault(require("chalk"));
const middleware_1 = __importDefault(require("./middleware"));
const std_1 = require("./utils/std");
yargs_1.default
    .commandDir('commands', {
    extensions: ['js', 'ts'],
    exclude: /\.d\.ts/,
})
    .completion('completion', chalk_1.default.green('generate bash completion script'))
    .middleware(middleware_1.default)
    .recommendCommands()
    .scriptName('resolve-cloud')
    .strict()
    .wrap(128)
    .demandCommand(1)
    .help()
    .showHelpOnFail(true)
    .usage(`\n${chalk_1.default.blue('$0')} <command> [sub-command] [arguments]\n${chalk_1.default.blue('$0')} <command> --help\n${chalk_1.default.blue('$0')} --version`)
    .option('help', { hidden: true })
    .option('version', { hidden: true, alias: 'v' })
    .option('verbosity', {
    describe: 'set output verbosity level',
    type: 'string',
    choices: ['silent', 'normal', 'debug', 'trace'],
})
    .option('api-url', {
    describe: 'resolve api url',
    type: 'string',
})
    .group(['verbosity', 'api-url'], 'Global options:')
    .fail((msg, err) => {
    if (msg) {
        std_1.logger.error(msg);
        process.exit(1);
    }
    if (err) {
        std_1.logger.error(err.stack);
        process.exit(1);
    }
})
    .check((argv) => {
    for (const [key, value] of Object.entries(argv)) {
        if (typeof value === 'string' && value === '') {
            return `Invalid option "${key}" value`;
        }
    }
    return true;
})
    .parse();
//# sourceMappingURL=index.js.map